@@ -1,7 +1,7 @@
 # This function estimates any of the the NA parameters, or returns c and d if all parameters are given
 CKrigcoefs <- function(xy,
                      nuniquerows, ## as given by selectFn
-                     covfnparamA=NA,
+                     covfnparamA=NA, # excluding smoohtness, but output covfnparam includes it.
                      lambdaA=NA,
                      minSmoothness=blackbox.getOption("minSmoothness"),
                      maxSmoothness=blackbox.getOption("maxSmoothness"),
@@ -12,7 +12,20 @@ CKrigcoefs <- function(xy,
 ){
   nrowxy <- nrow(xy)
   ncolxy <- ncol(xy)
-  optimise <- any(is.na(c(covfnparamA,lambdaA)))
+  # Test on length(covfnparamA) assumes that when scale params are known, smoothness is too 
+  # (=> testing smoothness range is irrelevant). 
+  # In standard usage either covfnparamA is zero-length (and lambda is unknown)
+  #  => the estimation of cov params is performed
+  # or all parameters (including lambda) are known and no optimization is performed.
+  # It is also possible that the user sets a scale parameter, and and smoothness through min/maxSmoothness,
+  # but lambda still needs to be estimated: this is a subcase of the optimize case.
+  # (we might only test lambda to distinguish the cases)
+  # The user is currently not allowed to set all correlation params through the CovFnParam vector: 
+  # input CovFnParam should contain scale parameters only.
+  # The user is also not allowed to provide lambda (through blackbox.getOption("lambdaEst")).
+  varCorrpars <- (length(covfnparamA)< ncolxy ## shorter than scale params+smoothness
+                  || any(is.na(covfnparamA))) 
+  optimise <- (varCorrpars || is.na(lambdaA))
   method <- intersect(optimizers,c("bobyqa","L-BFGS-B","lbfgsb3")) ## non-default methods
   if(length(method)==0L) method <- "NLOPT_LN_BOBYQA" ## default for this part of code.
   if(length(method)!=1L) stop("length(method)!=1L in CKrigcoefs") ## incompatible with switch below
@@ -38,10 +51,9 @@ CKrigcoefs <- function(xy,
   } else if ( ! optimise ) {
     resu <- Krig_coef_Wrapper(covfnparamA,lambdaA)[c("c","d","CKrigidx")] # throwing away u and D
     # do not deleteCSmooth(), CSmooth pointer stored in CKrigptrTable
-  } else {
-    if (any(is.na(covfnparamA))) { ## estim covfnparamA
+  } else { # optimize
+    if (varCorrpars) { ## need to estim scale params and/or smoohtness (not sure that it can estimate only some of them)
       if ( is.null(initCovFnParam) ) initCovFnParam <- rep(0, ncolxy)
-      minSmoothness <- min(maxSmoothness,max(minSmoothness,1.001)); # >1, cf def Matern
       xx <- xy[,-ncolxy,drop=FALSE]
       KgLow <- apply(xx,2,min)
       KgUp <- apply(xx,2,max)
@@ -51,7 +63,9 @@ CKrigcoefs <- function(xy,
       lower <- maxrange/(GCVlowerFactor*nuniquerows)
       upper <- maxrange*GCVupperFactor
       init_factor <- rep(init_factor,length(lower))
-      if (maxSmoothness-minSmoothness>1e-6) { # fixed Smoothness case
+      minSmoothness <- min(maxSmoothness,max(minSmoothness,1.001)); # >1, cf def Matern
+      varSmoothness <- (maxSmoothness-minSmoothness>1e-6)
+      if (varSmoothness) { # Variable Smoothness case
         maxrange <- c(maxrange,maxSmoothness-minSmoothness)
         lower <- c(lower,minSmoothness)
         upper <- c(upper,maxSmoothness)
@@ -98,18 +112,19 @@ CKrigcoefs <- function(xy,
                        fixedSmoothness=fixedSmoothness,returnFnvalue=TRUE)
         solution <- optr$solution
       } else stop("Unknown 'method' in CKrigcoefs()")
-      resu <- list(covfnparam=solution,fnEvalCount=getFnEvalCount(),method=method)
-    } else { ## no estim of covfnparam but we will estimate lambda
-      resu <- list(covfnparam=covfnparamA)
-      fixedSmoothness <- numeric(0) ## local value for GCV_lamVar_covFix_Wrapper() call:
+      solution <- c(solution,fixedSmoothness) # required when minSmoothness=maxSmoothness
+      resu <- list(covfnparam=solution, # full including smoothness whether fixed or estimated
+                   fnEvalCount=getFnEvalCount(),method=method)
+    } else { ## no estim of scale nor smoohtness but we will estimate lambda
+      resu <- list(covfnparam=c(covfnparamA,maxSmoothness)) # also including smoothness
     }
-    if (is.na(lambdaA)) resu$lambda <- GCV_lamVar_covFix_Wrapper(resu$covfnparam,fixedSmoothness=fixedSmoothness,returnFnvalue=FALSE)
+    if (is.na(lambdaA)) resu$lambda <- GCV_lamVar_covFix_Wrapper(resu$covfnparam,fixedSmoothness=numeric(0),returnFnvalue=FALSE)
     deleteCSmooth() ## this code conditional on optimisation
   }
   return(resu) # is a list with elements depending on call:
-  # if optimise covfnparam -> covfnparam, lambda, fnEvalCount, method
-  # else if optimise lambda -> input covfnparamA, lambda
-  # else c("c","d","CKrigidx")
+  # if optimise covfnparam -> returns covfnparam, lambda, fnEvalCount, method
+  # else if optimise lambda -> returns (input covfnparamA), lambda
+  # else returns c("c","d","CKrigidx")
 } ## end def CKrigcoefs
 
 # R-style implementation of default values
