@@ -15,12 +15,18 @@ findglobalMLE <- function(initptinfK) {
   } else if("IM" %in% DemographicModel) {
     blob <- c(blob, list(Nratio=canonized$Nratio))
   }
+  
   plotOptions <- blackbox.getOption("plotOptions")
   oneDimCIvars <- blackbox.getOption("oneDimCIvars")
   if ( length(intersect(DemographicModel, c("OnePopVarSize", "OnePopFounderFlush", "IM")))>0) {
     if ( !("IM" %in% DemographicModel) && ( ("DgmuProf" %innc% plotOptions) || ("Dgmu" %innc% oneDimCIvars) ) )  blob <- c(blob, list(Dgmu=canonized$Dgmu))
     if ( ("TgmuProf" %innc% plotOptions) || ("Tgmu" %innc% oneDimCIvars) )  blob <- c(blob, list(Tgmu=canonized$Tgmu))
   }
+  if ( length(intersect(DemographicModel, c("Npop", "IM")))>0) {
+    blob <- c(blob, list(NMratio=canonized$NMratio), list(mratio=canonized$mratio)) ## RL, not sur... here only to keep the goop parameter order e.g. for IM Theta, Q1, M1, M2, T,Nratio,Tmu,Mratio,miovermu,m2overmu
+    if ( ("movermuProf" %innc% plotOptions) || ("m1overmu" %innc% oneDimCIvars) )  blob <- c(blob, list(m1overmu=canonized$m1overmu))
+    if ( ("movermuProf" %innc% plotOptions) || ("m2overmu" %innc% oneDimCIvars) )  blob <- c(blob, list(m2overmu=canonized$m2overmu))
+  }
   blob <-  c(blob, canonVP=list(canonized$canonVP))
   return(blob)
 }
